@@ -70,9 +70,9 @@ Extender - Dynamically enhance Perl objects with additional methods from other m
     my $object = {};
 
     # Extend $object with methods from 'List::Util'
-    Extend($object, 'List::Util', 'sum', 'max');
+    Extend($object, 'Hash::Util', 'keys', 'values');
 
-    # Now $object has 'sum' and 'max' methods from 'List::Util'
+    # Now $object has 'keys' and 'values' methods from 'Hash::Util'
 
 =cut
 
@@ -177,12 +177,9 @@ sub Extends {
 
     use Extender;
 
-    my $object = {};
-
-    # Original method definition
-    sub original_method {
+    my $object = Extends({}, original_method => sub {
         return "Original method";
-    }
+    });
 
     # Override the 'original_method' in $object
     Override($object, 'original_method', sub { return "New method"; });
@@ -238,12 +235,9 @@ sub Override {
 
     use Extender;
 
-    my $object = {};
-
-    # Original method definition
-    sub original_method {
+    my $object = Extends({}, original_method => sub {
         return "Original method";
-    }
+    });
 
     # Create an alias 'new_alias' for 'original_method' in $object
     Alias($object, 'original_method', 'new_alias');
@@ -298,15 +292,9 @@ sub Alias {
 
     use Extender;
 
-    my $object = {};
-
-    # Define a method
-    sub example_method {
+    my $object = Extends({}, example_method => sub {
         return "Example method";
-    }
-
-    # Extend $object with the method
-    Extend($object, 'ExampleModule', 'example_method');
+    });
 
     # Unload the method from $object
     Unload($object, 'example_method');
@@ -363,20 +351,17 @@ sub Unload {
 
     use Extender;
 
-    my $object = {};
-
-    # Define a new method
-    sub custom_method {
+    my $object = Extends({}, custom_method => sub {
         my ($self, $arg1, $arg2) = @_;
         return "Custom method called with args: $arg1, $arg2";
-    }
-
-    # Add the method to $object
-    AddMethod($object, 'custom_method', \&custom_method);
+    })->AddMethod(custom_method2 => sub {
+        my ($self, $arg1, $arg2) = @_;
+        return "Custom method2 called with args: $arg1, $arg2";
+    });
 
     # Using the added method
-    my $result = $object->custom_method('foo', 'bar');
-    print "$result\n";  # Outputs: Custom method called with args: foo, bar
+    my $result = $object->custom_method2('foo', 'bar');
+    print "$result\n";  # Outputs: Custom method2 called with args: foo, bar
 
 =cut
 
@@ -430,11 +415,7 @@ sub AddMethod {
         return $result;
     }
 
-    my $object = {};
-    $object->{counter} = 0;
-
-    # Add a method to increment a counter
-    $object->{increment} = sub { $object->{counter}++ };
+    my $object = AddMethod({counter => 0}, increment => sub { my ($object)=@_; $object->{counter}++ });
 
     # Decorate the 'increment' method with timing_decorator
     Decorate($object, 'increment', \&timing_decorator);
@@ -507,16 +488,16 @@ sub Decorate {
 
 =head3 Example:
 
-    use Extender;
-
     # Define a role (mixin)
     package MyRole;
     sub foo { print "foo\n" }
     sub bar { print "bar\n" }
 
+    package main;
+    use Extender;
+
     # Apply the role to an object
-    my $object = {};
-    ApplyRole($object, 'MyRole');
+    my $object = ApplyRole({}, 'MyRole');
 
     # Call the role methods
     $object->foo();  # Outputs: foo
@@ -776,8 +757,7 @@ sub MooseCompat {
     use Extender;
 
     # Extend an object with methods from a module
-    my $object = MyClass->new();
-    Extend($object, 'Some::Class');
+    my $object = Extend(MyClass->new(), 'Some::Class');
 
     # Now $object can use any method from Some::Class
     $object->method1(1, 2, 3, 4);
@@ -787,8 +767,8 @@ sub MooseCompat {
     use Extender;
 
     # Extend an object with custom methods
-    my $object = MyClass->new();
-    Extends($object,
+    my $object = Extends(
+        MyClass->new(),
         greet => sub { my ($self, $name) = @_; print "Hello, $name!\n"; },
         custom_method => \&some_function,
     );
@@ -911,15 +891,15 @@ sub MooseCompat {
 
 =head2 Adding methods using anonymous subroutines and existing functions
 
-    use Extender;
-
     package MyClass;
     sub new {
         my $class = shift;
-        my $self = bless {}, $class;
-        return $self;
+        return bless {}, $class;
     }
 
+    package main;
+    use Extender;
+
     my $object = MyClass->new();
 
     Extends($object,
@@ -1055,7 +1035,6 @@ sub MooseCompat {
     }
 
     package main;
-
     use Extender;
 
     my $object = MyClass->new();
